package Daje::Database::View::VCompaniesUsers;
use Mojo::Base 'Daje::Database::View::Super::VCompaniesUsers', -base, -signatures;

# Autogenerated class Thu Mar  6 17:15:18 2025
# This class is generated once. Any over rides or special methods should be put here



1;

